@@ -139,14 +139,25 @@ class BaseValidator(metaclass=ABCMeta):
 
 
 class ValidateResult:
-    def __init__(self, spec=None, field=None, check=None, error=None):
-        self.spec = type(spec)
-        self.field = field
-        self.check = check
-        self.error = error
+    def __init__(self, spec=None, field=None, value=None, check=None, error=None):
+        # TODO: Output spec & check information when there's a debug message level for development.
+        self.__spec = type(spec)
+        self.__field = field
+        self.__value = value
+        self.__check = check
+        self.__error = error
 
-    def __str__(self):
-        return f'{self.spec}/{self.field}/{self.check}/{self.error}'
+    @property
+    def field(self):
+        return self.__field
+
+    @property
+    def value(self):
+        return self.__value
+
+    @property
+    def error(self):
+        return self.__error
 
 
 class UnknownFieldValue:
@@ -160,17 +171,20 @@ class CheckerOP(Enum):
 
 
 class Checker:
-    def __init__(self, checks, optional=False, op=CheckerOP.ALL, extra=None):
+    def __init__(self, checks, optional=False, allow_none=False, op=CheckerOP.ALL, extra=None):
         """
         checks: list of str(Check)
         optional: boolean
                   Set optional to True, the validation process will be passed if the field is absent
+        allow_none: boolean
+                  Set allow_none to True, the field value can be None
         op: CheckerOP
         extra: None or Dict
         """
         self.checks = checks or []
         self._op = op
         self._optional = optional
+        self._allow_none = allow_none
         self.extra = extra or {}
 
         self._ensure()
@@ -179,6 +193,10 @@ class Checker:
         if self._optional and len(self.checks) == 0:
             raise ValueError('Require at least 1 check when set optional to True')
 
+    @property
+    def allow_none(self):
+        return self._allow_none
+
     @property
     def allow_optional(self):
         return self._optional
@@ -190,3 +208,28 @@ class Checker:
     @property
     def is_op_all(self):
         return self._op == CheckerOP.ALL
+
+
+class MsgLv(Enum):
+    VAGUE = 'vague'
+    DEFAULT = 'default'
+
+
+# TODO: Can make this a per-spec-check scope feature
+__message_level = MsgLv.DEFAULT
+
+
+def get_msg_level():
+    return __message_level
+
+
+def reset_msg_level(vague=False):
+    """
+    Setting vague=True, all error messages will be replaced to 'field: XXX not well-formatted'.
+    Otherwise, the message is as usual showing the reason.
+    """
+    global __message_level
+    if vague:
+        __message_level = MsgLv.VAGUE
+    else:
+        __message_level = MsgLv.DEFAULT
