@@ -30,6 +30,7 @@ from data_spec_validator.spec import (
     Checker,
     CheckerOP,
     not_,
+    reset_msg_level,
     validate_data_spec,
 )
 from data_spec_validator.spec.validators import BaseValidator
@@ -91,6 +92,22 @@ class TestSpec(unittest.TestCase):
         nok_data = dict(none_field=3)
         assert is_something_error(TypeError, validate_data_spec, nok_data, _get_none_spec())
 
+    def test_allow_none(self):
+        def _get_allow_none_spec():
+            class AllowNoneSpec:
+                maybe_none_field = Checker([INT], allow_none=True)
+
+            return AllowNoneSpec
+
+        ok_data = dict(maybe_none_field=3)
+        assert validate_data_spec(ok_data, _get_allow_none_spec())
+
+        ok_data = dict(maybe_none_field=None)
+        assert validate_data_spec(ok_data, _get_allow_none_spec())
+
+        nok_data = dict(maybe_none_field='3')
+        assert is_something_error(TypeError, validate_data_spec, nok_data, _get_allow_none_spec())
+
     def test_bool(self):
         def _get_bool_spec():
             class BoolSpec:
@@ -331,7 +348,7 @@ class TestSpec(unittest.TestCase):
             ),
             bool_field=False,
         )
-        assert is_something_error(TypeError, validate_data_spec, nok_data, _get_spec())
+        assert is_something_error(LookupError, validate_data_spec, nok_data, _get_spec())
 
         nok_data = dict(
             int_field=1,
@@ -346,7 +363,7 @@ class TestSpec(unittest.TestCase):
             ),
             bool_field=False,
         )
-        assert is_something_error(TypeError, validate_data_spec, nok_data, _get_spec())
+        assert is_something_error(LookupError, validate_data_spec, nok_data, _get_spec())
 
     def test_list_of(self):
         def _get_list_of_spec_spec():
@@ -861,7 +878,7 @@ class TestSpec(unittest.TestCase):
         assert validate_data_spec(ok_data, _get_any_key_exists_spec())
 
         nok_data = dict(key=1)
-        assert is_something_error(ValueError, validate_data_spec, nok_data, _get_any_key_exists_spec())
+        assert is_something_error(LookupError, validate_data_spec, nok_data, _get_any_key_exists_spec())
 
     def test_key_coexist(self):
         def _get_key_coexist_spec():
@@ -874,10 +891,10 @@ class TestSpec(unittest.TestCase):
         assert validate_data_spec(ok_data, _get_key_coexist_spec())
 
         nok_data = dict(key2=1)
-        assert is_something_error(ValueError, validate_data_spec, nok_data, _get_key_coexist_spec())
+        assert is_something_error(LookupError, validate_data_spec, nok_data, _get_key_coexist_spec())
 
         nok_data = dict(key=1)
-        assert is_something_error(ValueError, validate_data_spec, nok_data, _get_key_coexist_spec())
+        assert is_something_error(LookupError, validate_data_spec, nok_data, _get_key_coexist_spec())
 
     def test_not_checker(self):
         def _get_non_bool_spec():
@@ -973,5 +990,27 @@ class TestCustomSpec(unittest.TestCase):
         assert is_something_error(ValueError, validate_data_spec, nok_data, _get_gt_10_spec())
 
 
+class TestMessageLevel(unittest.TestCase):
+    def test_vague_message(self):
+        def _get_int_spec():
+            class IntSpec:
+                int_field = Checker([INT])
+
+            return IntSpec
+
+        reset_msg_level(vague=True)
+        nok_data = dict(int_field='3')
+        try:
+            validate_data_spec(nok_data, _get_int_spec())
+        except Exception as e:
+            assert str(e).find('well-formatted') >= 0
+
+        reset_msg_level()
+        try:
+            validate_data_spec(nok_data, _get_int_spec())
+        except Exception as e:
+            assert str(e).find('reason') >= 0
+
+
 if __name__ == '__main__':
     unittest.main()
